import { AuthApi } from './AuthApi';
import { AuthService } from './AuthService';

export class LibAuth {
    private static instance: LibAuth;

    private authService: AuthService = AuthService.getInstance();

    private constructor() {}

    public static getInstance(): LibAuth {
        if (!LibAuth.instance) {
            LibAuth.instance = new LibAuth();
        }
        return LibAuth.instance;
    }

    public async startSession(userData: any) {
        await this.authService.startSession(userData);
    }

    public showMessageExpiredMenu() {
        AuthService.getInstance().showMessageExpiredMenu();
    }

    public async logout() {
        await this.authService.logout();
    }

    public async updateSession(user: object, accessProfile: object[], otherSessionValues: object) {
        return new Promise((resolve, reject) => {
            AuthApi.updateSession(user, accessProfile, otherSessionValues).then((response) => {
                if (!response.data.user) {
                    reject(response);
                }
                localStorage.setItem('LOGIN_USER', response.data.user);
                resolve(true);
            }).catch((error) => {
                reject(error);
            });
        });
    }

    public saveCollectedData(collectionIds: any, operationId: any, productId = null,
                             operatorCode = null, operatorName = null, organizationId = null): Promise<any> {
        return AuthApi.saveCollectedData(collectionIds, operationId, productId, operatorCode, operatorName, organizationId);
    }

    public async startLib() {
        await this.authService.checkExpiredSession();
    }
}
