import { Config } from '@zeedhi/core';
import { AxiosRequestConfig } from 'axios';
import { AuthService } from '../Authentication/AuthService';

export class AddRequestSuccess {
    public static routesIgnoredInRequest = ['/lib_logout', '/login'];

    public static validateUserRoute = '/validateUser';

    public static validateExpiredSessionRoute = '/lib_validateExpiredSession';

    public static addHeaders(config: AxiosRequestConfig) {
        const route: string = config.url || '';
        if (!AddRequestSuccess.routesIgnoredInRequest.includes(route)) {
            const token = localStorage.getItem('LOGIN_TOKEN');
            const hash = localStorage.getItem('LOGIN_HASH');
            const productId = localStorage.getItem('PRODUCT_ID');
            let keepConnected = localStorage.getItem('LOGIN_KEEP_CONNECTED');
            if (token) {
                config.headers['OAuth-Token'] = token;
            }
            if (hash) {
                config.headers['OAuth-Hash'] = hash;
                config.headers['OAuth-Project'] = productId;
            }
            if (route === AddRequestSuccess.validateUserRoute) {
                keepConnected = 'Yes';
            }
            config.headers['OAuth-KeepConnected'] = keepConnected;
        }
    }

    public static createSessionTime(config: AxiosRequestConfig) {
        if (config.url && config.url !== AddRequestSuccess.validateExpiredSessionRoute && config.url !== `${Config.env.loginEndPoint}/validateUser`) {
            AuthService.getInstance().factoryExpiredSessionMethod();
        }
    }
}
