import { DialogService, IComponentRender } from '@zeedhi/common';
import { I18n } from '@zeedhi/core';

export class MessageServices {
    public static showMessage(message: string, params: any = {}, type: string = 'warning', buttons?: IComponentRender[]) {
		DialogService.show({
			name: 'lib-dialog',
			type,
			title: `ALE_${type.toUpperCase()}`,
			text: I18n.translate(message, params),
			buttons,
		});
    }

    public static defaultError(response: any) {
		const defaultMessage = 'ERR_UNEXPECTED_ERROR';
		if (response && response.data && response.data.error) {
			let { data } = response;
			const { error } = data;
			if (MessageServices.isJson(data)) {
				data = JSON.parse(data);
			}
			const params = data.messageParams || {};
			const messageCode = data.messageCode || error || 'ERR_UNEXPECTED_ERROR';
			const message = messageCode.split('Exception: ').pop();
			MessageServices.showMessage(message, params, 'error');
		} else {
			this.showMessage(defaultMessage, {}, 'error');
		}
    }

    private static showInvalidPasswordMaskMessage(messageCode: string, params: any) {
		let messages = '';
		params.forEach((param: any) => {
			if (param && param.EXISTS_MASK && param.INVALID_MASK) {
				const message = I18n.translate(param.MESSAGE);
				messages += `<li align="left">${I18n.translate(message, param.PARAMS)}</li>`;
			}
		});
		MessageServices.showMessage(messageCode, { validations: messages });
	}

    private static isJson(str: string) {
		let result = null;
		try {
			result = JSON.parse(str);
		} catch (e) {
			// nothing to do
		}
		return result;
	}
}
